@@ -1,7 +1,7 @@
 package App::BencherUtils;
 
 our $DATE = '2016-01-22'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -234,6 +234,7 @@ sub bencher_all {
                     action => 'bench',
                     scenario_module => $sn,
                     precision_limit => $args{precision_limit},
+                    (note => $args{note}) x !!(exists $args{note}),
                 );
                 return err("Can't bench", $res) unless $res->[0] == 200;
                 my $filename = "$args{results_dir}/$sn_encoded.$timestamp.json";
@@ -258,7 +259,10 @@ sub bencher_all {
                     $res = Bencher::bencher(
                         action => 'bench',
                         module_startup => 1,
-                        scenario_module => $sn);
+                        scenario_module => $sn,
+                        precision_limit => $args{precision_limit},
+                        (note => $args{note}) x !!(exists $args{note}),
+                    );
                     return err("Can't bench (module_startup)", $res)
                         unless $res->[0] == 200;
                     my $filename = "$args{results_dir}/$sn_encoded.module_startup.".
@@ -542,7 +546,7 @@ App::BencherUtils - Utilities related to bencher
 
 =head1 VERSION
 
-This document describes version 0.07 of App::BencherUtils (from Perl distribution App-BencherUtils), released on 2016-01-22.
+This document describes version 0.08 of App::BencherUtils (from Perl distribution App-BencherUtils), released on 2016-01-22.
 
 =head1 SYNOPSIS
 
